import bpy
import os
from pathlib import Path

# Function to load the node group from the .blend file
def load_node_group(blend_file, group_name):
    # Get the addon directory using bpy.utils.user_resource
    addon_directory = Path(bpy.utils.user_resource('SCRIPTS', path="addons"))
    blend_file_path = addon_directory / "mesh_planes_pro" / blend_file
    
    with bpy.data.libraries.load(str(blend_file_path), link=False) as (data_from, data_to):
        if group_name in data_from.node_groups:
            data_to.node_groups = [group_name]
    
    return bpy.data.node_groups.get(group_name)
    

# Function to change the material of the object
def change_material(obj, node_group):
    # Get the active material
    mat = obj.active_material

    # Remove all nodes except the Image Texture and Material Output
    for node in mat.node_tree.nodes:
        if node.name not in {"Image Texture", "Material Output"}:
            mat.node_tree.nodes.remove(node)

    # Get the existing image texture node
    existing_img_node = mat.node_tree.nodes.get("Image Texture")

    if existing_img_node:
        # Add the node group
        node_group_node = mat.node_tree.nodes.new('ShaderNodeGroup')
        node_group_node.node_tree = node_group
        node_group_node.location = (0, 0)

        # Connect the color output of the existing image texture to the input of the node group
        mat.node_tree.links.new(existing_img_node.outputs["Color"], node_group_node.inputs[0])
        
        # Connect the alpha output of the existing image texture to the second input of the node group (assuming this is the Alpha input)
        if "Alpha" in existing_img_node.outputs:
            mat.node_tree.links.new(existing_img_node.outputs["Alpha"], node_group_node.inputs[1])  # Assuming input 1 is for Alpha

        # Ensure Material Output node is present
        material_output_node = mat.node_tree.nodes.get("Material Output")

        if material_output_node:
            # Connect the output of the Node Group to the Material Output
            mat.node_tree.links.new(node_group_node.outputs[0], material_output_node.inputs["Surface"])
        else:
            # If there's no Material Output, report an error
            print("Material Output node not found.")
    else:
        # If there is no existing Image Texture node, report an error
        print("No existing Image Texture node found.")

# Define the operator
class OBJECT_OT_my_operator(bpy.types.Operator):
    bl_idname = "object.my_operator"
    bl_label = "Mesh Planes Pro"

    def execute(self, context):
        obj = context.object

        # Get the relative path to the blend file containing the node group
        addon_directory = os.path.dirname(__file__)
        blend_file = os.path.join(addon_directory, "Mesh_Plane_Pro.blend")

        # Load the node group from the blend file
        node_group = load_node_group(blend_file, "Mesh Plane Pro")

        if node_group:
            change_material(obj, node_group)
        else:
            self.report({'ERROR'}, "Node group not found in the blend file.")
        
        return {'FINISHED'}

# Define the menu item
def menu_func(self, context):
    self.layout.operator(OBJECT_OT_my_operator.bl_idname)

# Register the operator and add it to the menu
def register():
    bpy.utils.register_class(OBJECT_OT_my_operator)
    bpy.types.VIEW3D_MT_object_context_menu.append(menu_func)

# Unregister the operator and remove it from the menu
def unregister():
    bpy.utils.unregister_class(OBJECT_OT_my_operator)
    bpy.types.VIEW3D_MT_object_context_menu.remove(menu_func)

# Register the add-on
if __name__ == "__main__":
    register()
